@@ -74,7 +74,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.10.3-P2
+		echo VERSION=9.10.4-P3
 		exit 0
 		;;
 	--cflags)
@@ -165,7 +165,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -ldl -lcap -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -lm -ldl"
+		libs="$libs  -ldl -lcap -ljson-c -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -lm -ldl"
 	fi
 	echo $libs
 fi
